<?php
/**
* MyPhotoCoursePlugin.class.php
* 
* Plugin zum Verwalten von Photoalben in Veranstaltungen
* 
* @author               Jan Kulmann <jankul@zmml.uni-bremen.de>
*
* DEDICATION
*
* This plugin is dedicated to my one and only very best girl friend Nadine.
*
*/

// +---------------------------------------------------------------------------+
// This file is NOT part of Stud.IP
// Copyright (C) 2007 Jan Kulmann <jankul@zmml.uni-bremen.de>
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+

require_once("classes/myphoto/MyPhoto.class.php");
require_once("classes/myphoto/Photo.class.php");
require_once("classes/myphoto/Album.class.php");
require_once("classes/myphoto/Comment.class.php");
require_once("classes/myphoto/Controller.class.php");
require_once("classes/scorm/ScormExport.class.php");
require_once ("lib/functions.php");
require_once ("lib/messaging.inc.php");

class MyPhotoCoursePlugin extends AbstractStudIPStandardPlugin {

	var $view;
	var $items_per_page = 16;
	var $mp;
	var $licenses;
	var $mp_working_mode = 'course';

	function MyPhotoCoursePlugin(){
		parent::AbstractStudIPStandardPlugin();
		bindtextdomain('mp',dirname(__FILE__).'/locale');
		$this->setPluginIconName('images/myphoto_icon.jpg');
		$this->mp = new MyPhoto($this->mp_working_mode);
		include('include/config.inc.php');
                $this->licenses = $LICENSE;
	}
	
	function setPluginpath($newpath){
		parent::setPluginpath($newpath);
		$this->mp->setPluginobject($this);
		$this->buildMenu();
	}

	function buildMenu(){
		$tab = new PluginNavigation();
		$tab->setDisplayname(_("MyPhotos"));
		$tab->setActive();

		if ($GLOBALS['perm']->have_studip_perm("tutor",$GLOBALS['SessSemName'][1])) {
			$subnav = new PluginNavigation();
			$subnav->setDisplayname(_("Neues Album"));
			$subnav->setActive();
			$subnav->setLinkParam("new_album");
			$tab->addSubmenu($subnav);
		}
		$subnav2 = new PluginNavigation();
		$subnav2->setDisplayname(_("Alben bearbeiten"));
		$subnav2->setActive();
		$subnav2->setLinkParam("admin_mode");
		$tab->addSubmenu($subnav2);

		$this->setNavigation($tab); 
		$this->mp->set_homepage_view(FALSE);
		$this->mp->set_range_id($GLOBALS['SessSemName'][1]);
	}

	function getNavigation() {
		return $this->navigation;
	}

	function getPluginName() {
		return "MyPhotos";
	}

	function show() {
		$GLOBALS['perm']->check('autor');
		
		$this->mp->get_stylesheets();

		$this->view = "show";
		$modus = $_REQUEST['modus'];
		$c = new Controller();
		// Sind wir berechtigt?
		if ($GLOBALS['perm']->have_studip_perm("tutor",$GLOBALS['SessSemName'][1]) && $_REQUEST['plugin_subnavi_params'] == "new_album") {
			$this->mp->new_album();
		} else if ($GLOBALS['perm']->have_studip_perm("autor",$GLOBALS['SessSemName'][1]) && $_REQUEST['plugin_subnavi_params'] == "admin_mode") {
			$messaging=new messaging;
			
			// modus....
			if ($modus == "scorm_export") {
                                $a = new Album();
                                $a->load($_REQUEST['album_id']);
                                $scorm = new ScormExport($a, $this->getPluginpath(), $this->mp->get_range_id());
                                $scorm->initialize();
                                if ($scorm->error) {
					echo $scorm->error;
					unset($modus);
                                } else {
                                        $modus = "view_album";
					$m = sprintf(_("Sie k&ouml;nnen die Datei %s<B>hier</B>%s herunterladen."),"<A HREF=\"".GetDownloadLink($scorm->getExportFilename(),"scormexport.zip",2)."\">","</A>");
					parse_msg("msg".$m);
                                }
                        }
			if ($modus == "del_photo") {
				$p = new Photo();
				$p->load($_REQUEST['photo_id']);
				$p_user_id = $p->get_user_id();
				$a = new Album();
				$a->load($p->get_album_id());
				if ($a->is_in_range($GLOBALS['SessSemName'][1]) && Controller::haveEditPerms($a,$this->mp->get_range_id())) {
					$p->delete();
					if ($_REQUEST['photo_id'] == $a->get_start_photo_id()) {
						$a->set_start_photo_id("");
						$a->save();
					}
					if ($p_user_id != $GLOBALS['auth']->auth['uid']) {
						$msg = sprintf(_("Ein Foto im Album \"%s\" wurde von einer/einem DozentIn der Veranstaltung **%s** oder der Administration gelscht."),$a->get_titel(),$GLOBALS['SessSemName'][0]);
						$messaging->insert_message(mysql_escape_string($msg), get_username($p_user_id), "____%system%____", FALSE, FALSE, 1, FALSE, _("Foto gelscht"));
					}
					parse_msg("msg"._("Das Foto wurde gel&ouml;scht."));
				}
				$modus = "view_album";
			}
			if ($modus == "del_album") {
				$a = new Album();
				$a->load($_REQUEST['album_id']);
				$a_user_id = $a->get_user_id();
				$titel = $a->get_titel();
				if ($a->is_in_range($GLOBALS['SessSemName'][1]) && Controller::haveEditPerms($a,$this->mp->get_range_id())) {
					$a->delete();
					if ($a_user_id != $GLOBALS['auth']->auth['uid']) {
						$msg = sprintf(_("Das Album \"%s\" wurde von einer/einem DozentIn der Veranstaltung **%s** oder der Administration gelscht."),$titel,$GLOBALS['SessSemName'][0]);
						$messaging->insert_message(mysql_escape_string($msg), get_username($a_user_id), "____%system%____", FALSE, FALSE, 1, FALSE, _("Album gelscht"));
					}
					parse_msg("msg"._("Das Album wurde gel&ouml;scht."));
				}
				$modus = FALSE;
			}
			if ($modus == "del_comment") {
				$comment = new Comment();
				$comment->load($_REQUEST['comment_id']);
				$p = new Photo();
				$p->load($_REQUEST['photo_id']);
				$a = new Album();
				$a->load($p->get_album_id());
				if ($a->is_in_range($GLOBALS['SessSemName'][1]) && Controller::haveEditPerms($a,$this->mp->get_range_id())) {
					$comment->delete();
					if ($p->get_user_id() != $GLOBALS['auth']->auth['uid']) {
						$a = new Album();
						$a->load($p->get_album_id());
						$msg = sprintf(_("Ein Kommentar im Album \"%s\" wurde von einer/einem DozentIn der Veranstaltung **%s** oder der Administration gelscht."),$a->get_titel(),$GLOBALS['SessSemName'][0]);
						$messaging->insert_message(mysql_escape_string($msg), get_username($p->get_user_id()), "____%system%____", FALSE, FALSE, 1, FALSE, _("Kommentar gelscht"));
					}
					parse_msg("msg"._("Der Kommentar wurde gel&ouml;scht."));
				}
				$modus = "show_photo_maxsize";
			}
			if ($modus == "add_album") {
				if (strlen(trim($_REQUEST['titel'])) > 0) {
					$a = new Album();
					$a->set_titel(trim($_REQUEST['titel']));
					$a->set_untertitel(trim($_REQUEST['untertitel']));
					$a->set_beschreibung(trim($_REQUEST['beschreibung']));
					$a->set_user_id($GLOBALS['auth']->auth['uid']);
					$a->set_mkdate(time());
					$a->save();
					$a->add_range($GLOBALS['SessSemName'][1], $GLOBALS['auth']->auth['perm']);
					parse_msg("msg"._("Das Album wurde erstellt."));
					$modus = "view_album";
					$_REQUEST['album_id'] = $a->get_album_id();
				} else $modus = FALSE;
			}
			if ($modus == "save_album") {
				if (strlen(trim($_REQUEST['titel'])) > 0) {
					$sortierung = explode("photos[]=", preg_replace(array("/\&/"),array(""),$_REQUEST['sortierung']));
					$a = new Album();
					$a->load($_REQUEST['album_id']);
					if (Controller::haveEditPerms($a,$this->mp->get_range_id())) {
						$a->set_titel(trim($_REQUEST['titel']));
						$a->set_untertitel(trim($_REQUEST['untertitel']));
						$a->set_beschreibung(trim($_REQUEST['beschreibung']));
						$a->set_public($_REQUEST['public']);
						$a->set_allow_comments($_REQUEST['allow_comments']);
						$a->set_start_photo_id($_REQUEST['photo_id']);
						$a->set_edit_mode($GLOBALS['SessSemName'][1],$_REQUEST['edit_mode']);
						$a->save();
						$count = 0;
						foreach ($sortierung as $sort) {
							if (trim($sort) != "") {
								Photo::update_sort($sort, $count, $GLOBALS['SessSemName'][1]);
								$count++;
							}
						}
						parse_msg("msg"._("Die Einstellungen wurden gespeichert."));
					}
				}
				$modus = "view_album";
			}
			if ($modus == "save_photo") {
				$p = new Photo();
                                $p->load($_REQUEST['photo_id']);
				$a = new Album();
				$a->load($p->get_album_id());
				if (Controller::haveEditPerms($a,$this->mp->get_range_id())) {
	                                $old_album_id = $p->get_album_id();
        	                        $p->set_titel($_REQUEST['titel']);
                	                $p->set_beschreibung($_REQUEST['beschreibung']);
					$p->set_license((array_key_exists($_REQUEST['photo_license_id'],$this->licenses) ? $_REQUEST['photo_license_id'] : ""));
                        	        if ($_REQUEST['photo2album_move_id'] != "") {
                                	        $p->set_album_id($_REQUEST['photo2album_move_id']);
                                        	$p->save();
	                                        parse_msg("msg"._("Das Foto wurde verschoben."));
        	                                $modus = "view_album";
                	                        $_REQUEST['album_id'] = $old_album_id;
                        	        } else {
                                	        $p->save();
						$p->setTags(trim($_REQUEST['tags']));
                                        	parse_msg("msg"._("Das Foto wurde gepeichert."));
	                                        $modus = "show_photo_maxsize";
					}
                                }
			}
			if ($modus == "make_comment") {
				if (check_ticket($_REQUEST['ticket'])) {
					$co = new Comment();
					$co->set_photo_id($_REQUEST['photo_id']);
					$co->set_user_id($GLOBALS['auth']->auth['uid']);
					$co->set_mkdate(time());
					$co->set_comment($_REQUEST['comment']);
					$co->save();
				}
				$modus = "show_photo_maxsize";
			}
			if ($modus == "show_photo_maxsize") {
                                $p = new Photo();
                                $p->load($_REQUEST['photo_id']);
				$a = new Album();
				$a->load($p->get_album_id());
				if (Controller::haveEditPerms($a,$this->mp->get_range_id()) && $_REQUEST['rotate'] && ($_REQUEST['rotate'] == 'left' || $_REQUEST['rotate'] == 'right')) {
                                        $img = imagecreatefromstring(base64_decode($p->get_file_content()));
                                        $img_thumb = imagecreatefromstring(base64_decode($p->get_file_content_thumb()));
                                        if ($_REQUEST['rotate'] == "left")
                                                $degree = 90;
                                        else
                                                $degree = 270;

                                        $img2 = $c->rotate($img, $degree);
                                        $img2_thumb = $c->rotate($img_thumb, $degree);

                                        $c_file = $GLOBALS['TMP_PATH']."/".md5(uniqid(time()));
                                        $t_file = $GLOBALS['TMP_PATH']."/".md5(uniqid(time()));
                                        if ($p->get_ext() == "gif") {
                                                $f = imagegif($img2, $c_file);
                                                $f_thumb = imagegif($img2_thumb, $t_file);
                                        } else {
                                                $f = imagejpeg($img2, $c_file);
                                                $f_thumb = imagejpeg($img2_thumb, $t_file);
                                        }
                                        $p->set_file_content(base64_encode(file_get_contents($c_file)), base64_encode(file_get_contents($t_file)), TRUE);
                                        unlink($c_file);
                                        unlink($t_file);
                                }
				$this->mp->admin_show_foto_maxsize($_REQUEST['photo_id']);
			}
			if ($modus == "add_photos") {
				$this->mp->new_file_upload(PluginEngine::getLink($this,array()), $_REQUEST['album_id']);
			}
			if ($modus == "foto_upload") {
				$a = new Album();
				$a->load($_REQUEST['album_id']);
				if (Controller::haveEditPerms($a,$this->mp->get_range_id())) {
					if (is_array($_FILES['imgfile']) && $_REQUEST['album_id']) {
						$msg = $c->add_new_foto($_FILES['imgfile']['tmp_name'], $_FILES['imgfile']['size'], $_FILES['imgfile']['name'], $_REQUEST['album_id'], $_REQUEST['titel'], $_REQUEST['beschreibung']);
						if ($msg)
							parse_msg($msg);
					}
					$modus = "view_album";
				} else $modus = FALSE;
			}
			// ZIP-Upload
			if ($modus == "zip_upload") {
				$a = new Album();
				$a->load($_REQUEST['album_id']);
				if (Controller::haveEditPerms($a,$this->mp->get_range_id())) {
					if (is_array($_FILES['zipfile']) && $_REQUEST['album_id']) {
						$msg = $c->add_new_zip($_FILES['zipfile']['tmp_name'], $_FILES['zipfile']['size'], $_FILES['zipfile']['name'], $_REQUEST['album_id']);
						if ($msg)
							parse_msg($msg);
					}
					$modus = "view_album";
				} else $modus = FALSE;
			}
			if ($modus == "view_album") {
				$this->mp->admin_view_album($_REQUEST['album_id']);
			}
			
			if (!$modus)
				$this->mp->admin_show_albums();
		} else { // normaler Teilnehmer oder Tutor
			if (($album_id = $this->mp->the_one_and_only_album()) && !$modus) {
				$modus = "view_album";
				$_REQUEST['album_id'] = $album_id;
			}
			if ($modus != "") {
				if ($modus == "view_album") {
		        	        $this->mp->public_view_album($_REQUEST['album_id']);
                		}
				if ($modus == "make_comment") {
					if (check_ticket($_REQUEST['ticket'])) {
						$co = new Comment();
						$co->set_photo_id($_REQUEST['photo_id']);
						$co->set_user_id($GLOBALS['auth']->auth['uid']);
						$co->set_mkdate(time());
						$co->set_comment($_REQUEST['comment']);
						$co->save();
						$p = new Photo();
						$p->load($_REQUEST['photo_id']);
						$a = new Album();
						$a->load($p->get_album_id());
						$messaging=new messaging;
						$msg = sprintf(_("%s hat ein Foto im Album \"%s\" kommentiert."),get_vorname($GLOBALS['auth']->auth["uid"]),$a->get_titel());
						$msg .= "\n\nKommentar:\n".kill_format($co->get_comment());
						$messaging->insert_message(mysql_escape_string($msg), get_username($p->get_user_id()), $GLOBALS['auth']->auth["uid"], FALSE, FALSE, 1, FALSE, _("Foto-Kommentar"));
					}
	                                $modus = "show_photo_maxsize";
        	                }
				if ($modus == "show_photo_maxsize") {
					$this->mp->public_show_foto_maxsize($_REQUEST['photo_id']);
				}
				if ($modus == "searchPhotos") {
	                                $val = base64_decode(escapeshellcmd(basename(trim($_REQUEST['txt']))));
        	                        $page = escapeshellcmd(basename(trim($_REQUEST['page'])));
                	                $what = escapeshellcmd(basename(trim($_REQUEST['what'])));
                        	        if (!$page) $page = 1;
                                	if ($val) {
                                        	$this->mp->publicShowSearchResults($val, $page, $what);
	                                }
        	                }
			} else
				$this->mp->public_show_albums(TRUE); 
		} 
	}

}

?>
