<?php
/**
* MyPhotoPlugin.class.php
* 
* Plugin zum Verwalten von Photoalben (Hauptklasse)
* 
* @author               Jan Kulmann <jankul@zmml.uni-bremen.de>
*/

// +---------------------------------------------------------------------------+
// This file is NOT part of Stud.IP
// Copyright (C) 2007 Jan Kulmann <jankul@zmml.uni-bremen.de>
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+

require_once("Photo.class.php");
require_once("Album.class.php");
require_once("Comment.class.php");
require_once("Controller.class.php");
require_once("SlideShowHandler.class.php");
require_once ("lib/functions.php");
require_once ("lib/dates.inc.php");
require_once ("lib/messaging.inc.php");
require_once('vendor/flexi/template_factory.php');

class MyPhoto {

	var $view = "show";
	var $items_per_page = 16;
	var $pluginpath;
	var $requesteduser;
	var $plugincobject;
	var $range_id;
	var $homepage_view = TRUE;
	var $save_txt;
	var $template_path;
        var $factory;
	var $licenses;
	var $mp_working_mode;

	function getLink($pluginobj, $params, $view='show') {
		if ($_REQUEST['plugin_subnavi_params'])
			$params = array_merge($params, array('plugin_subnavi_params'=>$_REQUEST['plugin_subnavi_params']));

		return PluginEngine::getLink($pluginobj,$params, $view);
	}

	function MyPhoto($mp_working_mode = 'homepage') {
		$this->mp_working_mode = $mp_working_mode;
		$this->template_path = dirname(__FILE__).'/../../templates/html/flexi';
                $this->factory = new Flexi_TemplateFactory($this->template_path);
		$this->save_txt = dgettext('mp',"Speichern nicht vergessen!");
		include(dirname(__FILE__).'/../../include/config.inc.php');
		$this->licenses = $LICENSE;
	}

	function set_range_id($s) {
		$this->range_id = $s;
	}

	function get_range_id() {
		return $this->range_id;
	}

	function set_homepage_view($b=TRUE) {
		$this->homepage_view = $b;
	}

	function get_homepage_view() {
		return $this->homepage_view;
	}

	function setPluginobject(&$p) {
		$this->pluginobject = $p;
		$this->pluginobject->view = (strlen(trim($this->pluginobject->view)) > 0 ? trim($this->pluginobject->view) : "show");
	}

	// ist nur ein Album sichtbar und wenn ja, welche ID hat es?
	function the_one_and_only_album() {
		$c = new Controller();
		$albums = $c->get_all_public_albums($this->range_id);
		if (count($albums) == 1) {
			return $albums[0]->get_album_id();
		} else
			return FALSE;
	}

	function publicShowTagCloud() {
		$c = new Controller();
		$tags = $c->getTagCounter(100);
                //if (count($tags) < 5) return;
                $template = $this->factory->open('show_tag_cloud');
		$template->set_attribute('have_tags', (count($c->getTagCounter()) > 19 ? TRUE : FALSE));
		$template->set_attribute('have_best_ratings', (count($c->getBestRatedPublicPhotos()) > 0 ? TRUE : FALSE));
		$template->set_attribute('have_most_ratings', (count($c->getMostRatedPublicPhotos()) > 0 ? TRUE : FALSE));
                $template->set_attribute('tags', $tags);
                echo $template->render();
        }

	function publicShowSearchResults($txt, $page=1, $what='tags') {
		if (!$this->get_homepage_view())
                        $url = $this->getLink($this->pluginobject,array("a"=>"1"));
                else $url = $GLOBALS['PHP_SELF'] . "?a=1";

                $c = new Controller();
                $photos = $c->search_query($txt, $what);
                $template_photos = array();
		if (count($photos) > 0) {
			foreach ($photos as $p) {
				$calc_ratings = $p->calcRatings();
                                $comment_count = $c->get_number_of_all_photo_comments($p->get_photo_id());
				$template = $this->factory->open('public_single_photo');
				$template->set_attribute('calc_ratings', $calc_ratings);
		                $template->set_attribute('p', $p);
		                $template->set_attribute('range_id', $this->get_range_id());
		                $template->set_attribute('comment_count', $comment_count);
		                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
		                $template->set_attribute('url', $url."&modus=show_photo_maxsize&photo_id=".$p->get_photo_id()."#ankermp");
                		array_push($template_photos, $template->render());
			}
		}
		$template = $this->factory->open('show_search_results');
                $template->set_attribute('template_photos', $template_photos);
                $template->set_attribute('css_uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath().'/css');
                $template->set_attribute('img_uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath().'/images');
		$template->set_attribute('items_per_page', $this->items_per_page);
		$template->set_attribute('mp_working_mode', $this->mp_working_mode);
		$template->set_attribute('url', $url);
		$template->set_attribute('what', $what);
		$template->set_attribute('txt', $txt);
                $template->set_attribute('page', $page);
                echo $template->render();
        }

	function get_lytebox() {
		echo "<link rel=\"stylesheet\" href=\"".$this->pluginobject->getPluginURL()."/lib/lytebox/lytebox.css\" type=\"text/css\" media=\"screen\" />\n";
		echo "<script src=\"".$this->pluginobject->getPluginURL()."/lib/lytebox/lytebox.js\" type=\"text/javascript\"></script>\n";
	}

	function get_stylesheets() {
		echo "<LINK REL=\"stylesheet\" HREF=\"".$this->pluginobject->getPluginURL()."/css/style.css\" TYPE=\"text/css\" />\n";
		echo "<LINK REL=\"stylesheet\" HREF=\"".$this->pluginobject->getPluginURL()."/css/tagcloud.css\" TYPE=\"text/css\" />\n";
		echo "<link href=\"".$this->pluginobject->getPluginURL()."/css/star_rating.css\" rel=\"stylesheet\" type=\"text/css\" media=\"all\">\n";
	}

	function createInfoBox ($imgLogo, $dont_display=TRUE) {
		$c = new Controller();
		$quota_size = $c->get_absolut_content_size_in_db($GLOBALS['auth']->auth['uid']);
		$quota = $c->translate_disksize($quota_size);
		if ($quota_size > $c->max_quota_size)
			$quota = "<SPAN STYLE=\"color:red;\">$quota</SPAN>";
		else
			$quota = "<SPAN STYLE=\"color:red;\">$quota</SPAN>";
		$infos = array();
		array_push($infos, array ("icon" => "i.gif", "text" => dgettext('mp',"Mit MyPhotos k&ouml;nnen sehr schnell Fotoalben angelegt werden.")));
		array_push($infos, array ("icon" => "eigene2.gif", "text" => dgettext('mp',"Jedes Album und jedes Foto kann individuell beschrieben werden.")));
		array_push($infos, array ("icon" => "home.gif", "text" => dgettext('mp',"Um das Startbild eines Albums festzulegen, einfach den Radio-Button oberhalb des gew&uuml;schten Bildes ausw&auml;hlen und das Album speichern.")));
		array_push($infos, array ("icon" => "icon-guest.gif", "text" => dgettext('mp',"Mit der integrierten Kommentarfunktion werden Eindr&uuml;cke ausgetauscht.")));
		array_push($infos, array ("icon" => "calendar_public.gif", "text" => dgettext('mp',"Jedes Album kann separat sichtbar oder unsichtbar f&uuml;r andere geschaltet werden. Der Eigent&uuml;mer eines Album entscheidet selbst, ob Kommentare zu einzelnen Fotos erlaubt sein sollen.")));
		array_push($infos, array ("icon" => "cont_folder_add.gif", "text" => dgettext('mp',"&Uuml;ber die ZIP-Uploadfunktion werden Bildersammlungen bequem hochgeladen.")));
		array_push($infos, array ("icon" => "rewind.gif", "text" => dgettext('mp',"Innerhalb eines Albums k&ouml;nnen Fotos per drag and drop sortiert werden.")));
		array_push($infos, array ("icon" => "vcardexport.gif", "text" => sprintf(dgettext('mp',"Der Export erzeugt ein %s%s kompatibles Archiv, welches Sie z.B. in ILIAS weiterverwenden k&ouml;nnen."),"<SPAN STYLE=\"font-weight:bold; color:green;\">SCORM2004</SPAN>","<IMG SRC=\"".$GLOBALS['ASSETS_URL']."/images/symbol06.gif\">")));
		array_push($infos, array ("icon" => "i.gif", "text" => sprintf(dgettext('mp',"Die exportierten Archive sind %s und %s konform <BR><SPAN STYLE=\"font-size:smaller;\">(getestet mit SCORM 2004 3rd Edition Conformance Test Suite Version 1.0.1)</SPAN>"),"<SPAN STYLE=\"font-weight:bold; color:green;\">SCORM 2004 3rd Edition</SPAN>","<SPAN STYLE=\"font-weight:bold; color:green;\">CP CAM 1.0</SPAN>")));
		array_push($infos, array ("icon" => "zip-icon.gif", "text" => sprintf(dgettext('mp',"Speicherverbrauch: <BR><B>%s</B> von <B>%s</B>"),$quota,$c->translate_disksize($c->max_quota_size))));
		$infobox = array (array ("kategorie" => dgettext('mp',"Information:"), "eintrag"   => $infos));
		return print_infobox ($infobox, $imgLogo, $dont_display);
	}

	function new_album() {
		$template = $this->factory->open('new_album_form');
                $template->set_attribute('uri', $this->getLink($this->pluginobject,array()));
                $template->set_attribute('infobox', $this->createInfoBox("modules.jpg"));
                echo $template->render();
	}

	function new_file_upload($link, $album_id) {
		$template = $this->factory->open('new_file_upload_form');
                $template->set_attribute('link', $link);
                $template->set_attribute('album_id', $album_id);
                echo $template->render();
        }
	
	function public_view_album($album_id) {
		$url = "";

		if (!$this->get_homepage_view())
			$url = $this->getLink($this->pluginobject,array("a"=>"1"));
		else $url = $GLOBALS['PHP_SELF'] . "?a=1";

		$this->get_lytebox();

		$page = ($_REQUEST['page'] ? $_REQUEST['page'] : 1);

		$a = new Album();
		$a->load($album_id);
		$c = new Controller();
		$photos = $c->get_all_photos_in_album($album_id);
		$first_p = new Photo();
		$first_p->load($c->get_first_photo_id($album_id));
		$s = new SlideShowHandler();
		$s->set_album_id($album_id);
		$s->set_plugin_path($this->pluginobject->getPluginpath());

		$template_photos = array();
		if (count($photos) > 0) {
			foreach ($photos as $p) {
				$calc_ratings = $p->calcRatings();
                                $comment_count = ($a->get_allow_comments() == 1 ? $c->get_number_of_all_photo_comments($p->get_photo_id()) : 0);
				$template = $this->factory->open('public_single_photo');
				$template->set_attribute('calc_ratings', $calc_ratings);
		                $template->set_attribute('p', $p);
		                $template->set_attribute('range_id', $this->get_range_id());
		                $template->set_attribute('comment_count', $comment_count);
		                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
		                $template->set_attribute('url', $url.'&photo_id='.$p->get_photo_id().'&modus=show_photo_maxsize&username='.get_username($this->range_id).'#ankermp');
                		array_push($template_photos, $template->render());
			}
		}
		//if (count($template_photos) > 0) {
			$template = $this->factory->open('public_view_album');
		        $template->set_attribute('a', $a);
		        $template->set_attribute('s', $s);
		        $template->set_attribute('the_one_and_only_album', $this->the_one_and_only_album());
		        $template->set_attribute('items_per_page', $this->items_per_page);
		        $template->set_attribute('page', $page);
		        $template->set_attribute('template_photos', $template_photos);
		        $template->set_attribute('range_id', $this->get_range_id());
		        $template->set_attribute('first_p', $first_p);
		        $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
		        $template->set_attribute('url', $url);
			echo $template->render();
		//}
	}
	
	function admin_view_album($album_id) {
		$a = new Album();
		$a->load($album_id);
		$c = new Controller();
		$photos = $c->get_all_photos_in_album($album_id);

		$seminare = $c->get_seminare($album_id, $this->get_range_id());
		$current_sem_ranges = $a->get_current_ranges();
		$edit_mode = $a->get_edit_mode($this->get_range_id());

		$template_photos = array();
		if (count($photos) > 0) {
			foreach ($photos as $p) {
				$calc_ratings = $p->calcRatings();
                                $comment_count = $c->get_number_of_all_photo_comments($p->get_photo_id());
				$template = $this->factory->open('admin_single_photo');
				$template->set_attribute('calc_ratings', $calc_ratings);
		                $template->set_attribute('a', $a);
		                $template->set_attribute('p', $p);
		                $template->set_attribute('comment_count', $comment_count);
		                $template->set_attribute('save_txt', $this->save_txt);
		                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
		                $template->set_attribute('max_size_uri', $this->getLink($this->pluginobject,array("photo_id"=>$p->get_photo_id(), "modus"=>"show_photo_maxsize"),$this->view));
                		array_push($template_photos, $template->render());
			}
		}

		$template = $this->factory->open('admin_view_album');
		$template->set_attribute('a', $a);
		$template->set_attribute('infobox', $this->createInfoBox("modules.jpg"));
		$template->set_attribute('save_txt', $this->save_txt);
		$template->set_attribute('template_photos', $template_photos);
		$template->set_attribute('edit_mode', $edit_mode);
		$template->set_attribute('current_sem_ranges', $current_sem_ranges);
		$template->set_attribute('range_id', $this->get_range_id());
		$template->set_attribute('seminare', $seminare);
		$template->set_attribute('add_photos_uri', $this->getLink($this->pluginobject,array("modus"=>"add_photos", "album_id"=>$album_id)));
		$template->set_attribute('delete_album_uri', $this->getLink($this->pluginobject,array("modus"=>"del_album","album_id"=>$a->get_album_id())));
		$template->set_attribute('scorm_export_uri', $this->getLink($this->pluginobject,array("modus"=>"scorm_export","album_id"=>$a->get_album_id(),"titel"=>urlencode($a->get_titel()))));
		$template->set_attribute('plugin_uri', $this->getLink($this->pluginobject,array()));
		$template->set_attribute('uri',$GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
		echo $template->render();
	}

	function public_show_foto_maxsize($photo_id) {
		$url = "";

		if (!$this->get_homepage_view())
			$url = $this->getLink($this->pluginobject,array("a"=>"1"));
		else $url = $GLOBALS['PHP_SELF'] . "?a=1";

		$p = new Photo();
		$p->load($photo_id);

		$a = new Album();
		$a->load($p->get_album_id());
		$prev_id = Album::get_prev_photo_id($p->get_album_id(), $p->get_photo_id());
		$next_id = Album::get_next_photo_id($p->get_album_id(), $p->get_photo_id());
		$calc_ratings = $p->calcRatings();

		$studipticket = Seminar_Session::get_ticket();

		$rating_template = $this->factory->open('rating');
		$rating_template->set_attribute('css_uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath().'/css');
		$rating_template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
                $rating_template->set_attribute('p', $p);
                $rating_template->set_attribute('can_rate', $p->canRate($GLOBALS['auth']->auth['uid']));
                $rating_template->set_attribute('current', $calc_ratings['durch']);
                $rating_template->set_attribute('rating_width', $calc_ratings['proz']);
	
		$template = $this->factory->open('public_show_foto_maxsize');
                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
                $template->set_attribute('url', $url);
                $template->set_attribute('ticket', $studipticket);
                $template->set_attribute('comments', $this->public_get_comments($p->get_photo_id()));
		$template->set_attribute('rating', $rating_template->render());
		$template->set_attribute('rating_counter', $calc_ratings['rating_txt']);
		$template->set_attribute('a', $a);
		$template->set_attribute('p', $p);
		$template->set_attribute('licenses', $this->licenses);
                $template->set_attribute('can_rate', $p->canRate($GLOBALS['auth']->auth['uid']));
		$template->set_attribute('range_id', $this->get_range_id());
		$template->set_attribute('calc_ratings', $calc_ratings);
		$template->set_attribute('prev_id', $prev_id);
		$template->set_attribute('next_id', $next_id);
                echo $template->render();
	}

	function public_get_comments($photo_id) {
		$c = new Controller();
		$comments = $c->get_all_photo_comments($photo_id, 10);
		$template_comments = array();
                foreach ($comments as $c) {
                        $comment_template = $this->factory->open('single_comment');
                        $comment_template->set_attribute('comment',$c);
                        array_push($template_comments, $comment_template->render());
                }
		return $template_comments;
	}

	function admin_show_foto_maxsize($photo_id) {
		$c = new Controller();

		$p = new Photo();
		$p->load($photo_id);

		$a = new Album();
		$a->load($p->get_album_id());
		$prev_id = Album::get_prev_photo_id($p->get_album_id(), $p->get_photo_id());
		$next_id = Album::get_next_photo_id($p->get_album_id(), $p->get_photo_id());
		$alt_ranges = $c->get_alternative_ranges($p->get_photo_id());
		$img = imagecreatefromstring(base64_decode($p->get_file_content()));
		$comments = $c->get_all_photo_comments($p->get_photo_id());

		$calc_ratings = $p->calcRatings();
		$studipticket = Seminar_Session::get_ticket();

		$rating_template = $this->factory->open('rating');
		$rating_template->set_attribute('css_uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath().'/css');
		$rating_template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
                $rating_template->set_attribute('p', $p);
                $rating_template->set_attribute('can_rate', $p->canRate($GLOBALS['auth']->auth['uid']));
                $rating_template->set_attribute('current', $calc_ratings['durch']);
                $rating_template->set_attribute('rating_width', $calc_ratings['proz']);

		$template = $this->factory->open('admin_show_foto_maxsize');
		$template->set_attribute('rating', $rating_template->render());
                $template->set_attribute('rating_counter', $calc_ratings['rating_txt']);
		$template->set_attribute('calc_ratings', $calc_ratings);
                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
                $template->set_attribute('plugin_uri', $this->getLink($this->pluginobject,array()));
		$template->set_attribute('delete_tag_uri', $this->getLink($this->pluginobject,array("modus"=>"show_photo_maxsize","modus2"=>"delete_tag","photo_id"=>$p->get_photo_id())));
		$template->set_attribute('delete_photo_uri', $this->getLink($this->pluginobject,array("modus"=>"del_photo","photo_id"=>$p->get_photo_id(),"album_id"=>$p->get_album_id())));

		$template->set_attribute('img_uri', $GLOBALS['ASSETS_URL']."/images/");
		$template->set_attribute('ticket', $studipticket);
		$template->set_attribute('a', $a);
		$template->set_attribute('p', $p);
		$template->set_attribute('comments', $comments);
		$template->set_attribute('licenses', $this->licenses);
		$template->set_attribute('rotate_left_uri', $this->getLink($this->pluginobject,array("photo_id"=>$p->get_photo_id(), "modus"=>"show_photo_maxsize", "rotate"=>"left"),$this->pluginobject->view));
		$template->set_attribute('rotate_right_uri', $this->getLink($this->pluginobject,array("photo_id"=>$p->get_photo_id(), "modus"=>"show_photo_maxsize", "rotate"=>"right"),$this->pluginobject->view));
		$template->set_attribute('alt_ranges', $alt_ranges);
		$template->set_attribute('infobox', $this->createInfoBox("modules.jpg"));
		$template->set_attribute('img_size', imagesx($img)."x".imagesy($img).' Pixel');
		$template->set_attribute('back_uri', $this->getLink($this->pluginobject,array("modus"=>"view_album","album_id"=>$a->get_album_id())));
		$template->set_attribute('delete_comment_uri', $this->getLink($this->pluginobject,array("modus"=>"del_comment","photo_id"=>$p->get_photo_id())));
		$template->set_attribute('prev_id', $prev_id);
		$template->set_attribute('next_id', $next_id);
		$template->set_attribute('prev_uri', $this->getLink($this->pluginobject,array("photo_id"=>$prev_id, "modus"=>"show_photo_maxsize"),$this->pluginobject->view));
		$template->set_attribute('next_uri', $this->getLink($this->pluginobject,array("photo_id"=>$next_id, "modus"=>"show_photo_maxsize"),$this->pluginobject->view));
                echo $template->render();
	}


	function public_show_albums() {
		$url = "";

		if (!$this->get_homepage_view())
			$url = $this->getLink($this->pluginobject,array())."?";
		else $url = $GLOBALS['PHP_SELF']."?a=1";


		$c = new Controller();
		$albums = $c->get_all_public_albums($this->get_range_id());
		$photos_in_album = array();
		foreach ($albums as $a) {
			$photos_in_album[$a->get_album_id()] = $c->get_all_photos_in_album($a->get_album_id());
		}

		$template = $this->factory->open('public_show_albums');
                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
                $template->set_attribute('url', $url);
		$template->set_attribute('photos_in_album', $photos_in_album);
		$template->set_attribute('albums', $albums);
		$template->set_attribute('username', get_username($this->get_range_id()));
                echo $template->render();
	}

	function public_show_albums_portal() {
		$c = new Controller();
		$albums = $c->get_all_public_portal_albums();

		// shuffle
		if (count($albums) > 3) {
			$visited = array();
			$tmp_albums = array();
			while (count($tmp_albums) < 3) {
				$r = rand(0,count($albums)-1);
				if (!in_array($r, $visited)) {
					array_push($visited, $r);
					array_push($tmp_albums, $albums[$r]);
				}
			}
			$albums = $tmp_albums;
		}
		$photos_in_album = array();
		foreach ($albums as $a) {
			$photos_in_album[$a->get_album_id()] = $c->get_all_photos_in_album($a->get_album_id());
		}

		$template = $this->factory->open('public_show_albums_portal');
                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
                $template->set_attribute('studip_uri', $GLOBALS['ABSOLUTE_URI_STUDIP']);
		$template->set_attribute('photos_in_album', $photos_in_album);
		$template->set_attribute('albums', $albums);
		$template->set_attribute('have_tags', (count($c->getTagCounter()) > 19 ? TRUE : FALSE));
		$template->set_attribute('have_best_ratings', (count($c->getBestRatedPublicPhotos()) > 0 ? TRUE : FALSE));
		$template->set_attribute('have_most_ratings', (count($c->getMostRatedPublicPhotos()) > 0 ? TRUE : FALSE));
		$template->set_attribute('username', get_username($this->get_range_id()));
                echo $template->render();
	}

	function publicShowRatedPhotosPortal($rating_mode = 'most', $page = 1) {
		$url = "index.php?a=1";
		$c = new Controller();
		if ($rating_mode == "most")
			$photos = $c->getMostRatedPublicPhotos();
		else
			$photos = $c->getBestRatedPublicPhotos();
		
		$template_photos = array();
		if (count($photos) > 0) {
			foreach ($photos as $p) {
				$calc_ratings = $p->calcRatings();
                                $comment_count = $c->get_number_of_all_photo_comments($p->get_photo_id());
				$template = $this->factory->open('public_single_photo');
		                $template->set_attribute('p', $p);
		                $template->set_attribute('comment_count', $comment_count);
		                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
		                $template->set_attribute('url', $url."&modus=show_photo_maxsize&photo_id=".$p->get_photo_id()."#ankermp");
		                $template->set_attribute('calc_ratings', $calc_ratings);
                		array_push($template_photos, $template->render());
			}
		}
		$template = $this->factory->open('public_view_photos_rated');
                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
                $template->set_attribute('studip_uri', $GLOBALS['ABSOLUTE_URI_STUDIP']);
		$template->set_attribute('items_per_page', $this->items_per_page);
		$template->set_attribute('rating_mode', $rating_mode);
		$template->set_attribute('page', $page);
		$template->set_attribute('have_tags', (count($c->getTagCounter()) > 19 ? TRUE : FALSE));
		$template->set_attribute('have_best_ratings', (count($c->getBestRatedPublicPhotos()) > 0 ? TRUE : FALSE));
		$template->set_attribute('have_most_ratings', (count($c->getMostRatedPublicPhotos()) > 0 ? TRUE : FALSE));
		$template->set_attribute('template_photos', $template_photos);
		$template->set_attribute('username', get_username($this->get_range_id()));
                echo $template->render();
	
	}

	function admin_show_albums() {
		$c = new Controller();

		$albums = $c->get_all_albums($this->get_range_id());

		$t_albums = $albums;
		$albums = array();
		if (count($t_albums) > 0) {
			foreach ($t_albums as $t) {
				if (Controller::haveEditPerms($t, $this->get_range_id()))
					array_push($albums, $t);
			}
		}
		
		$template_albums = array();
		if (count($albums) > 0) {
			foreach ($albums as $a) {
				$template = $this->factory->open('admin_single_album');
		                $template->set_attribute('a', $a);
		                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
		                $template->set_attribute('view_album_uri', $this->getLink($this->pluginobject,array("album_id"=>$a->get_album_id(), "modus"=>"view_album"),$this->pluginobject->view));
                		array_push($template_albums, $template->render());
			}

		}

		$template = $this->factory->open('admin_show_albums');
                $template->set_attribute('albums', $template_albums);
                $template->set_attribute('uri', $GLOBALS['ABSOLUTE_URI_STUDIP'].$this->pluginobject->getPluginpath());
                $template->set_attribute('infobox', $this->createInfoBox("modules.jpg"));
                $template->set_attribute('range_id', $this->get_range_id());
                echo $template->render();
	}

}

?>
