<?php
/**
* ScormExport.class.php
*
*
* @author               Jan Kulmann <jankul@zmml.uni-bremen.de>
*/

// +---------------------------------------------------------------------------+
// This file is NOT part of Stud.IP
// Copyright (C) 2007 Jan Kulmann <jankul@zmml.uni-bremen.de>
// +---------------------------------------------------------------------------+
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or any later version.
// +---------------------------------------------------------------------------+
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// +---------------------------------------------------------------------------+


require_once ("lib/functions.php");

require_once "ImsScormPackage.class.php";
require_once "Asset.class.php";
require_once "ShareableContentObject.class.php";

class ScormExport {

	var $export_path;
	var $content_path;
	var $error;
	var $titel;
	var $pluginpath;
	var $imsScormPackage;
	var $range_id;
	var $album_id;
	var $export_filename;
	var $scorm_files = array("adlcp_v1p3.xsd", "adlnav_v1p3.xsd", "imscp_v1p1.xsd", "imsss_v1p0.xsd", "lom.xsd", "xml.xsd");

	function ScormExport($a, $ppath, $range_id) {
		$this->pluginpath = $ppath;
		$this->export_path = $GLOBALS['TMP_PATH']."/".$a->get_album_id();
		$this->content_path = $this->export_path . "/res";
		$this->album_id = $a->get_album_id();
		$this->error = "";
		$this->titel = $a->get_titel();
		$this->range_id = $range_id;
		$this->export_filename = md5(time()).".zip";
		$this->imsScormPackage = new ImsScormPackage();
		$this->imsScormPackage->setAbsolutePath($this->export_path);
	}

	function initialize() {

		$c = new Controller();
		$a = new Album();
		$a->load($this->album_id);
		$m = new Asset();
		$m->setId("x".$a->get_album_id());
		$m->setRelativePath("res");
		$m->setFilename("index.html");
		$m->setContent($this->create_album_page($a));
		$this->imsScormPackage->addAsset($m);

		foreach ($c->get_all_photos_in_album($this->album_id) as $p) {
			$asset = new Asset();
			$asset->setId("x".$p->get_photo_id());
			$asset->setRelativePath("res");
			$asset->setFilename("p_".$p->get_photo_id().".html");
			$asset->setContent($this->create_photo_page($p));
			$this->imsScormPackage->addAsset($asset);
		
			$asset = new Asset();
			$asset->setId("x".$p->get_photo_id()."_thumb");
			$asset->setRelativePath("res/fotos");
			$asset->setFilename($p->get_photo_id()."_thumb.".$p->get_ext());
			$asset->setContent(base64_decode($p->get_file_content_thumb()));
			$this->imsScormPackage->addAsset($asset);

			$asset = new Asset();
			$asset->setId("x".$p->get_photo_id()."_max");
			$asset->setRelativePath("res/fotos");
			$asset->setFilename($p->get_photo_id().".".$p->get_ext());
			$asset->setContent(base64_decode($p->get_file_content()));
			$this->imsScormPackage->addAsset($asset);
		}

		$this->create_directory_structure();
		$this->create_manifest($this->album_id, $this->titel);
		$this->copy_template_files();

		$this->imsScormPackage->materialize();

		$this->content_packaging();
	}

	function getExportFilename() {
		return $this->export_filename;
	}

	function copy_template_files() {
		foreach ($this->scorm_files as $sf)
			copy($this->pluginpath."/templates/scorm/$sf",$this->export_path."/$sf");

		copy($this->pluginpath."/css/style.css",$this->content_path."/style.css");
	}


	function rmdir_r($path) {
		if (!is_dir($path)) {
			return false;
		}
		$stack = Array($path);
		while ($dir = array_pop($stack)) {
			if (@rmdir($dir)) {
				continue;
			}
			$stack[] = $dir;
			$dh = opendir($dir);
			while (($child = readdir($dh)) !== false) {
				if ($child[0] == '.') {
					continue;
				}
				$child = $dir . DIRECTORY_SEPARATOR . $child;
				if (is_dir($child)) {
					$stack[] = $child;
				} else {
					unlink($child);
				}
			}
		}
		return true;
	}

	function content_packaging() {
		$pwd = getcwd();
		chdir($this->export_path);
		$output = shell_exec($GLOBALS['ZIP_PATH']." -r ".$this->export_filename." .");
		if (file_exists($this->export_path."/".$this->export_filename)) {
			copy($this->export_path."/".$this->export_filename, $GLOBALS['TMP_PATH']."/export/".$this->export_filename);
		}
		chdir($pwd);
		$this->rmdir_r($this->export_path);
		
		return $output;
	}

	function create_directory_structure() {
		if (@mkdir($this->export_path)) {
			@mkdir($this->content_path);
			@mkdir($GLOBALS['TMP_PATH']."/export");
		} else
			$this->error = sprintf(dgettext('mp',"Fehler beim Anlegen des Start-Verzeichnisses (%s)!"),$this->export_path);
	}


	function create_manifest($id, $titel) {

		$titel = preg_replace(array("/\&/","/</","/>/"),array("","",""),$titel);

		$f = fopen($this->export_path."/imsmanifest.xml","w");

		$out = "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n";
		$out .= "<manifest identifier=\"u".$GLOBALS['auth']->auth['uid']."\" version=\"1.3\" \n";
		$out .= "      xmlns=\"http://www.imsglobal.org/xsd/imscp_v1p1\"  \n";
		$out .= "      xmlns:lom=\"http://ltsc.ieee.org/xsd/LOM\"  \n";
		$out .= "      xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance xml.xsd\"  \n";
		$out .= "      xmlns:adlcp=\"http://www.adlnet.org/xsd/adlcp_v1p3\"  \n";
		$out .= "      xmlns:imsss=\"http://www.imsglobal.org/xsd/imsss\"  \n";
		$out .= "      xmlns:adlnav=\"http://www.adlnet.org/xsd/adlnav_v1p3\"  \n";
		$out .= "      xsi:schemaLocation=\"http://www.imsglobal.org/xsd/imscp_v1p1 imscp_v1p1.xsd http://ltsc.ieee.org/xsd/LOM lom.xsd http://www.adlnet.org/xsd/adlcp_v1p3 adlcp_v1p3.xsd http://www.imsglobal.org/xsd/imsss imsss_v1p0.xsd http://www.adlnet.org/xsd/adlnav_v1p3 adlnav_v1p3.xsd\">  \n";
		$out .= "  <metadata>\n";
		$out .= "    <schema>ADL SCORM</schema>\n";
		$out .= "    <schemaversion>2004 3rd Edition</schemaversion>\n";
		$out .= "  </metadata>\n";

		$out .= "  <organizations default=\"o$id\">\n";
		$out .= "    <organization identifier=\"o$id\" structure=\"hierarchical\">\n";
		$out .= "      <title>".$titel."</title>\n";
		$out .= "      <item identifier=\"INDEX\" identifierref=\"RINDEX\">\n";
		$out .= "        <title>".$titel."</title>\n";
		$out .= "      </item>\n";
		$out .= "      <item identifier=\"PACKAGE_STYLE\" identifierref=\"RPACKAGE_STYLE\" isvisible=\"false\">\n";
		$out .= "        <title>Stylesheet</title>\n";
		$out .= "      </item>\n";
		$assets = $this->imsScormPackage->getAssets();
		$counter = 0;
		foreach ($assets as $a) {
			$counter++;
			$indexer = "i_";
			if (!(strpos($a->getId(),"_thumb")===false))
				$indexer = "t_";
			if (!(strpos($a->getId(),"_max")===false))
				$indexer = "m_";

			switch($indexer) {
				case 't_' : 
					$typ = "thumbnail";
					break;
				case 'm_' :
					$typ = "maxsize";
					break;
				default : 
					$typ = "index";
			}			

			$out .= "      <item identifier=\"".$indexer.$a->getId()."\" identifierref=\"".$a->getId()."\" isvisible=\"false\">\n";
			$out .= "        <title>Seite $counter ($typ)</title>\n";
			$out .= "      </item>\n";
		}
		$out .= "    </organization>\n";
		$out .= "  </organizations>\n";
		$out .= "  <resources>\n";
		$out .= "    <resource identifier=\"RINDEX\" type=\"webcontent\" adlcp:scormType=\"asset\" href=\"res/index.html\">\n";
		$out .= "      <file href=\"res/index.html\" />\n";
		$out .= "    </resource>\n";
		$out .= "    <resource identifier=\"RPACKAGE_STYLE\" type=\"webcontent\" adlcp:scormType=\"asset\" href=\"res/style.css\">\n";
		$out .= "      <file href=\"res/style.css\" />\n";
		$out .= "    </resource>\n";
		foreach ($assets as $a) {
			$out .= "    <resource identifier=\"".$a->getId()."\" type=\"webcontent\" adlcp:scormType=\"asset\" href=\"".$a->getRelativePath()."/".$a->getFilename()."\">\n";
			$out .= "      <file href=\"".$a->getRelativePath()."/".$a->getFilename()."\" />\n";
			$out .= "    </resource>\n";
		}
		$out .= "  </resources>\n";
		$out .= "</manifest>\n";

		fputs($f, $out);
		fclose($f);
	}

	function create_photo_page($p) {
		$prev_id = Album::get_prev_photo_id($p->get_album_id(), $p->get_photo_id());
		$next_id = Album::get_next_photo_id($p->get_album_id(), $p->get_photo_id());

		$out = "<HTML>\n";
		$out .= "  <HEAD>\n";
		$out .= "    <TITLE>".htmlReady($p->get_titel())."</TITLE>\n";
		$out .= "    <LINK REL=\"stylesheet\" HREF=\"style.css\" TYPE=\"text/css\" />\n";
		$out .= "  </HEAD>\n";
		$out .= "  <BODY>\n";
		$out .= "    <DIV STYLE=\"font-size:smaller; text-align:left\">\n";
		$out .= "      <A HREF=\"index.html\">zur&uuml;ck</A>\n";
		$out .= "    </DIV>\n";
		$out .= "    <DIV STYLE=\"font-size:smaller; text-align:center; height:30px;\">\n";
		if ($prev_id)
                        $out .= "     <A HREF=\"p_".$prev_id.".html\">"._("voriges Foto")."</A>\n";
                if ($prev_id && $next_id)
                        $out .= "     &nbsp;|&nbsp;\n";
                if ($next_id)
                        $out .= "     <A HREF=\"p_".$next_id.".html\">"._("n&auml;chstes Foto")."</A>\n";
		$out .= "    </DIV>\n";
		$out .= "    <DIV STYLE=\"text-align:center; height:30px;\">".htmlReady($p->get_titel())."</DIV> \n";
		$out .= "    <DIV STYLE=\"text-align:center;\"><FONT SIZE=\"-2\">von ".htmlReady(get_fullname($p->get_user_id()))."</FONT></DIV> \n";
		$out .= "    <DIV STYLE=\"text-align:center;\">\n";
		$out .= "      <IMG SRC=\"fotos/".$p->get_photo_id().".".$p->get_ext()."\" />\n";
		$out .= "    </DIV>\n";
		$out .= "    <CENTER>\n";
		$out .= "      <DIV CLASS=\"pub_photo_max_desc_body\" STYLE=\"margin:10px;\">".htmlReady($p->get_beschreibung())."</DIV> \n";
		$out .= "    </CENTER>\n";
		$out .= "  </BODY>\n";
		$out .= "</HTML>";

		return $out;
	}

	function create_album_page($a) {
		$c = new Controller();

		$out =  "<HTML>\n";
		$out .= "  <HEAD>\n";
		$out .= "    <TITLE>".htmlReady($a->get_titel())."</TITLE>\n";
		$out .= "    <LINK REL=\"stylesheet\" HREF=\"style.css\" TYPE=\"text/css\" />\n";
		$out .= "  </HEAD>\n";
		$out .= "  <BODY>\n";
		$out .= "    <H2>".htmlReady($a->get_titel())."</H2>\n";
		$out .= "<DIV STYLE=\"width:800px; text-align:center;\">\n";
		$photos = $c->get_all_photos_in_album($a->get_album_id());
		foreach ($photos as $p) {
			$out .= "  <DIV CLASS=\"pub_photo_frame_thumb\">\n";
			$out .= "    <DIV CLASS=\"pub_photo_frame_thumb_link\">\n";
			$out .= "      <A HREF=\"p_".$p->get_photo_id().".html\">\n";
      			$out .= "        <IMG SRC=\"fotos/".$p->get_photo_id()."_thumb.".$p->get_ext()."\" CLASS=\"pub_photo_frame_thumb_img\" BORDER=\"0\" />\n";
			$out .= "      </A>\n";
			$out .= "    </DIV>\n";
			$out .= "    <DIV CLASS=\"pub_photo_frame_thumb_title\">\n";
			$out .= "      <FONT SIZE=\"-2\">".(htmlReady(strlen($p->get_titel())>30 ? substr($p->get_titel(),0,30)."..." : $p->get_titel()))."</FONT>\n";
			$out .= "    </DIV>\n";
			$out .= "  </DIV>\n";
		}
		$out .= "    </DIV>\n";
		$out .= "  </BODY>\n";
		$out .= "</HTML>";
		return $out;
	}

}

?>
